@@ -1,6 +1,6 @@
 package Net::CLI::Interact;
 {
-  $Net::CLI::Interact::VERSION = '2.123612';
+  $Net::CLI::Interact::VERSION = '2.123620';
 }
 
 use Moo;
@@ -10,10 +10,6 @@ use MooX::Types::MooseLike::Base qw(InstanceOf Maybe Str HashRef);
 
 with 'Net::CLI::Interact::Role::Engine';
 
-our @default_log_categories = (
-    qw/dialogue dump engine object phrasebook prompt transport/,
-);
-
 has 'my_args' => (
     is => 'rwp',
     isa => HashRef,
@@ -29,6 +25,10 @@ sub BUILDARGS {
     return { my_args => $params };
 }
 
+sub default_log_categories {
+    return (qw/dialogue dump engine object phrasebook prompt transport/);
+}
+
 has 'log_at' => (
     is => 'rw',
     isa => Maybe[Str],
@@ -40,7 +40,7 @@ sub set_global_log_at {
     my ($self, $level) = @_;
     return unless defined $level and length $level;
     $self->logger->log_flags({
-        map {$_ => $level} @default_log_categories,
+        map {$_ => $level} default_log_categories()
     });
 }
 
@@ -120,7 +120,7 @@ Net::CLI::Interact - Toolkit for CLI Automation
 
 =head1 VERSION
 
-version 2.123612
+version 2.123620
 
 =head1 PURPOSE
 
